using System;
using Scripting;
using System.Net;
using System.Text;
using System.IO; 
using Newtonsoft.Json.Linq;
using System.Collections.Generic;

public static class WeatherForecast
{
	// WeatherCode List:
	// 1: clear sky
	// 2: few clouds
	// 3: scattered clouds
	// 4: broken clouds
	// 5: drizzle
	// 6: rain
	// 7: thunderstorm
	// 8: snow
	// 9: mist
	// 0: no information
	
	
	
	/// <summary>
	/// 
	/// </summary>
	/// <param name="description">Sieht man das?</param>
	/// <param name="weatherCode"></param>
    public static void Run(string APIKey, out string description, out int weatherCode, string longitude = "6,958281", string latitude = "50,941278", int ForecastByHours = 24)
    {
		if(string.IsNullOrEmpty(APIKey))
		{
			description = "Key missing";
			weatherCode = 0;
			return;
		}
		
        var request = (HttpWebRequest)WebRequest.Create("http://api.openweathermap.org/data/2.5/forecast?lat="+latitude+"&lon="+longitude+"&APPID="+APIKey);
		var response = (HttpWebResponse)request.GetResponse();
		var responseString = new StreamReader(response.GetResponseStream()).ReadToEnd();
		
		
		var information = JToken.Parse(responseString).ToObject<RootObject>();
		
		int listIndex = ForecastByHours / 3;
		
		if(information != null && information.list != null)
		{
			if(information.list.Count > listIndex)
			{
				var listItem = information.list[listIndex];
				var weatherItem = listItem.weather[0];
				description = weatherItem.description;
				
				if(weatherItem.id < 300) weatherCode = 7; // 2xx: thunderstorm
				else if(weatherItem.id < 400) weatherCode = 5; // 3xx: drizzle
				else if(weatherItem.id < 600) weatherCode = 6; // 5xx: rain
				else if(weatherItem.id < 700) weatherCode = 8; // 6xx: snow
				else if(weatherItem.id < 800) weatherCode = 9; // 7xx: mist/fog/tornado...
				else if(weatherItem.id == 800) weatherCode = 1; // 800: clear sky
				else if(weatherItem.id == 801) weatherCode = 2; // 801: few clouds
				else if(weatherItem.id == 802) weatherCode = 3; // 802: scattered clouds
				else weatherCode = 4; // 803 + 804: clouds
				
				return;
			}
			else
			{
				weatherCode = 0;
				description = "The forcast does not reach that far";
				return;
			}
		}
		
		// error case
		weatherCode = 0;
		description = "No Information";
    }
}

// generated class structure for json string parser
public class Main
{
    public double temp { get; set; }
    public double temp_min { get; set; }
    public double temp_max { get; set; }
    public double pressure { get; set; }
    public double sea_level { get; set; }
    public double grnd_level { get; set; }
    public int humidity { get; set; }
    public double temp_kf { get; set; }
}


public class Weather
{
    public int id { get; set; }
    public string main { get; set; }
    public string description { get; set; }
    public string icon { get; set; }
}

public class Clouds
{
    public int all { get; set; }
}

public class Wind
{
    public double speed { get; set; }
    public double deg { get; set; }
}

public class Sys
{
    public string pod { get; set; }
}

public class Rain
{
    public double __invalid_name__3h { get; set; }
}

public class List
{
    public int dt { get; set; }
    public Main main { get; set; }
    public List<Weather> weather { get; set; }
    public Clouds clouds { get; set; }
    public Wind wind { get; set; }
    public Sys sys { get; set; }
    public string dt_txt { get; set; }
    public Rain rain { get; set; }
}

public class Coord
{
    public double lat { get; set; }
    public double lon { get; set; }
}

public class City
{
    public int id { get; set; }
    public string name { get; set; }
    public Coord coord { get; set; }
    public string country { get; set; }
}

public class RootObject
{
    public string cod { get; set; }
    public double message { get; set; }
    public int cnt { get; set; }
    public List<List> list { get; set; }
    public City city { get; set; }
}
